import { SimklCalendarShow, SimklCalendarMonthRequest, SimklCalendarAnime, SimklCalendarMovie } from '../../models/simkl-calendar.model.cjs';
import { SimklClientEndpoint } from '../../models/simkl-client.model.cjs';
import '../../models/simkl-anime.model.cjs';
import '../../models/simkl-common.model.cjs';
import '../../models/simkl-episode.model.cjs';
import '../../models/simkl-rating.model.cjs';
import '@dvcol/base-http-client';
import '@dvcol/common-utils/common/models';
import '@dvcol/common-utils/http/fetch';

/**
 * Simkl provides separate JSON data calendar files that can be used to display the "Upcoming", "Next", "Schedule" or "Calendar" sections in your app or within show details cards.
 * The calendar files are generated every 6 hours and are cached on a CDN for 5 hours (you can check the last-modified HTTP Headers for the file generation date).
 *
 * @see [documentation]{@link https://simkl.docs.apiary.io/#reference/calendar/authorize-application}
 */
declare const calendar: {
    shows: {
        /**
         * Get the next 33 days of TV show releases.
         *
         * @see [documentation]{@link https://simkl.docs.apiary.io/#reference/calendar/authorize-application}
         */
        next: SimklClientEndpoint<Record<string, never>, SimklCalendarShow[], true>;
        /**
         * Calendars are updated for the past 12 months every 24 hours, and for the current month every 6 hours.
         *
         * @see [documentation]{@link https://simkl.docs.apiary.io/#reference/calendar/authorize-application}
         */
        month: SimklClientEndpoint<SimklCalendarMonthRequest, SimklCalendarShow[], true>;
    };
    anime: {
        /**
         * Get the next 33 days of anime releases.
         *
         * @see [documentation]{@link https://simkl.docs.apiary.io/#reference/calendar/authorize-application}
         */
        next: SimklClientEndpoint<Record<string, never>, SimklCalendarAnime[], true>;
        /**
         * Calendars are updated for the past 12 months every 24 hours, and for the current month every 6 hours.
         *
         * @see [documentation]{@link https://simkl.docs.apiary.io/#reference/calendar/authorize-application}
         */
        month: SimklClientEndpoint<SimklCalendarMonthRequest, SimklCalendarAnime[], true>;
    };
    movies: {
        /**
         * Get the next 33 days of movie releases.
         *
         * @see [documentation]{@link https://simkl.docs.apiary.io/#reference/calendar/authorize-application}
         */
        next: SimklClientEndpoint<Record<string, never>, SimklCalendarMovie[], true>;
        /**
         * Calendars are updated for the past 12 months every 24 hours, and for the current month every 6 hours.
         *
         * @see [documentation]{@link https://simkl.docs.apiary.io/#reference/calendar/authorize-application}
         */
        month: SimklClientEndpoint<SimklCalendarMonthRequest, SimklCalendarMovie[], true>;
    };
};

export { calendar };
