"use strict";Object.defineProperty(exports, "__esModule", {value: true});

var _chunkKBS52LMEcjs = require('./chunk-KBS52LME.cjs');


var _chunkS2NYHTYWcjs = require('./chunk-S2NYHTYW.cjs');



var _chunkP6V2PU4Bcjs = require('./chunk-P6V2PU4B.cjs');




var _chunkWQ6NSTT2cjs = require('./chunk-WQ6NSTT2.cjs');

// lib/api/endpoints/anime.endpoint.ts
var _http = require('@dvcol/common-utils/http');
var anime = {
  /**
   * Get detail info about the Anime
   *
   * Same as /tv/:id endpoint + added anime_type,en_title fields.
   *
   * @see [anime-summary](https://simkl.docs.apiary.io/reference/anime/summary/get-detail-info-about-the-anime}
   */
  id: new (0, _chunkWQ6NSTT2cjs.SimklClientEndpoint)({
    method: _http.HttpMethod.GET,
    url: "/anime/:id",
    opts: {
      auth: _chunkWQ6NSTT2cjs.SimklApiAuthType.Client,
      extends: _chunkWQ6NSTT2cjs.SimklApiExtended.Full,
      parameters: {
        path: {
          id: true
        },
        query: {
          extended: false
        }
      }
    },
    transform: _chunkKBS52LMEcjs.SimklApiTransform.Extends[_chunkWQ6NSTT2cjs.SimklApiExtended.Full]
  }),
  /**
   * Get Anime episodes
   *
   * @auth client
   * @extended full
   *
   * @see [anime-episodes](https://simkl.docs.apiary.io/reference/anime/episodes/get-anime-episodes}
   */
  episodes: new (0, _chunkWQ6NSTT2cjs.SimklClientEndpoint)({
    method: _http.HttpMethod.GET,
    url: "/anime/episodes/:id",
    opts: {
      auth: _chunkWQ6NSTT2cjs.SimklApiAuthType.Client,
      extends: _chunkWQ6NSTT2cjs.SimklApiExtended.Full,
      parameters: {
        path: {
          id: true
        },
        query: {
          extended: false
        }
      }
    },
    transform: _chunkKBS52LMEcjs.SimklApiTransform.Extends[_chunkWQ6NSTT2cjs.SimklApiExtended.Full]
  }),
  /**
   * Get trending anime series
   *
   * @auth client
   * @extended discover
   *
   * @see [anime-trending](https://simkl.docs.apiary.io/reference/anime/trending/get-trending-anime-series}
   */
  trending: new (0, _chunkWQ6NSTT2cjs.SimklClientEndpoint)({
    method: _http.HttpMethod.GET,
    url: "/anime/trending/:interval",
    opts: {
      auth: _chunkWQ6NSTT2cjs.SimklApiAuthType.Client,
      extends: _chunkWQ6NSTT2cjs.SimklApiExtended.Discover,
      parameters: {
        path: {
          interval: false
        },
        query: {
          extended: false
        }
      }
    },
    transform: _chunkKBS52LMEcjs.SimklApiTransform.Extends[_chunkWQ6NSTT2cjs.SimklApiExtended.Discover]
  }),
  /**
   * Get items filtered by genre, years etc...
   *
   * This endpoint accepts all parameters from the https://simkl.com/anime/all/, select the necessary filters and copy parameters from the url.
   * Genres API duplicates the urls of the Genres on the website so create a filter on the website and add it to genres API.
   *
   * @auth client
   * @pagination true
   *
   * @see [anime-genres](https://simkl.docs.apiary.io/reference/anime/genres/get-items-filtered-by-genre,-years-etc...}
   */
  genres: new (0, _chunkWQ6NSTT2cjs.SimklClientEndpoint)({
    method: _http.HttpMethod.GET,
    url: "/anime/genres/:genre/:type/:network/:year/:sort",
    seed: {
      genre: _chunkS2NYHTYWcjs.SimklAnimeGenreSection.All
    },
    opts: {
      auth: _chunkWQ6NSTT2cjs.SimklApiAuthType.Client,
      pagination: true,
      parameters: {
        path: {
          genre: false,
          type: false,
          network: false,
          year: false,
          sort: false
        },
        query: {
          page: false,
          limit: false
        }
      }
    }
  }),
  /**
   * Get latest premieres
   *
   * @auth client
   * @pagination true
   *
   * @see [anime-premieres](https://simkl.docs.apiary.io/reference/anime/premieres/get-latest-premieres}
   */
  premieres: new (0, _chunkWQ6NSTT2cjs.SimklClientEndpoint)({
    method: _http.HttpMethod.GET,
    url: "/anime/premieres/:param",
    seed: {
      param: _chunkP6V2PU4Bcjs.SimklPremiereParam.New
    },
    opts: {
      auth: _chunkWQ6NSTT2cjs.SimklApiAuthType.Client,
      pagination: true,
      parameters: {
        path: {
          param: true
        },
        query: {
          type: false,
          page: false,
          limit: false
        }
      }
    }
  }),
  /**
   * Get Airing Anime
   *
   * @auth client
   *
   * @see [anime-airing](https://simkl.docs.apiary.io/reference/anime/airing/get-airing-anime}
   */
  airing: new (0, _chunkWQ6NSTT2cjs.SimklClientEndpoint)({
    method: _http.HttpMethod.GET,
    url: "/anime/airing",
    opts: {
      auth: _chunkWQ6NSTT2cjs.SimklApiAuthType.Client,
      parameters: {
        query: {
          date: false,
          sort: false
        }
      }
    }
  }),
  /**
   * Get best of all Anime
   *
   * @auth client
   *
   * @see [anime-best](https://simkl.docs.apiary.io/reference/anime/best/get-best-of-all-anime}
   */
  best: new (0, _chunkWQ6NSTT2cjs.SimklClientEndpoint)({
    method: _http.HttpMethod.GET,
    url: "/anime/best/:filter",
    seed: {
      filter: _chunkP6V2PU4Bcjs.SimklBestFilter.All
    },
    opts: {
      auth: _chunkWQ6NSTT2cjs.SimklApiAuthType.Client,
      parameters: {
        path: {
          filter: true
        },
        query: {
          type: false
        }
      }
    }
  })
};



exports.anime = anime;
