import {
  Config
} from "./chunk-TD46ENXE.js";
import {
  SimklClientEndpoint
} from "./chunk-3HNK4KUT.js";

// lib/api/endpoints/calendar.endpoint.ts
import { HttpMethod } from "@dvcol/common-utils/http";
var calendar = {
  shows: {
    /**
     * Get the next 33 days of TV show releases.
     *
     * @see [documentation]{@link https://simkl.docs.apiary.io/#reference/calendar/authorize-application}
     */
    next: new SimklClientEndpoint({
      method: HttpMethod.GET,
      url: "/calendar/tv.json",
      opts: {
        endpoint: Config.Data
      }
    }),
    /**
     * Calendars are updated for the past 12 months every 24 hours, and for the current month every 6 hours.
     *
     * @see [documentation]{@link https://simkl.docs.apiary.io/#reference/calendar/authorize-application}
     */
    month: new SimklClientEndpoint({
      method: HttpMethod.GET,
      url: "/calendar/:year/:month/tv.json",
      seed: {
        year: (/* @__PURE__ */ new Date()).getFullYear(),
        month: (/* @__PURE__ */ new Date()).getMonth() + 1
      },
      opts: {
        endpoint: Config.Data,
        parameters: {
          path: {
            year: true,
            month: true
          }
        }
      }
    })
  },
  anime: {
    /**
     * Get the next 33 days of anime releases.
     *
     * @see [documentation]{@link https://simkl.docs.apiary.io/#reference/calendar/authorize-application}
     */
    next: new SimklClientEndpoint({
      method: HttpMethod.GET,
      url: "/calendar/anime.json",
      opts: {
        endpoint: Config.Data
      }
    }),
    /**
     * Calendars are updated for the past 12 months every 24 hours, and for the current month every 6 hours.
     *
     * @see [documentation]{@link https://simkl.docs.apiary.io/#reference/calendar/authorize-application}
     */
    month: new SimklClientEndpoint({
      method: HttpMethod.GET,
      url: "/calendar/:year/:month/anime.json",
      seed: {
        year: (/* @__PURE__ */ new Date()).getFullYear(),
        month: (/* @__PURE__ */ new Date()).getMonth() + 1
      },
      opts: {
        endpoint: Config.Data,
        parameters: {
          path: {
            year: true,
            month: true
          }
        }
      }
    })
  },
  movies: {
    /**
     * Get the next 33 days of movie releases.
     *
     * @see [documentation]{@link https://simkl.docs.apiary.io/#reference/calendar/authorize-application}
     */
    next: new SimklClientEndpoint({
      method: HttpMethod.GET,
      url: "/calendar/movie_release.json",
      opts: {
        endpoint: Config.Data
      }
    }),
    /**
     * Calendars are updated for the past 12 months every 24 hours, and for the current month every 6 hours.
     *
     * @see [documentation]{@link https://simkl.docs.apiary.io/#reference/calendar/authorize-application}
     */
    month: new SimklClientEndpoint({
      method: HttpMethod.GET,
      url: "/calendar/:year/:month/movie_release.json",
      seed: {
        year: (/* @__PURE__ */ new Date()).getFullYear(),
        month: (/* @__PURE__ */ new Date()).getMonth() + 1
      },
      opts: {
        endpoint: Config.Data,
        parameters: {
          path: {
            year: true,
            month: true
          }
        }
      }
    })
  }
};

export {
  calendar
};
