"use strict";Object.defineProperty(exports, "__esModule", {value: true});

var _chunkKBS52LMEcjs = require('./chunk-KBS52LME.cjs');


var _chunkIF2BWGZLcjs = require('./chunk-IF2BWGZL.cjs');



var _chunkP6V2PU4Bcjs = require('./chunk-P6V2PU4B.cjs');




var _chunkWQ6NSTT2cjs = require('./chunk-WQ6NSTT2.cjs');

// lib/api/endpoints/show.endpoint.ts
var _http = require('@dvcol/common-utils/http');
var show = {
  /**
   * Get detail info about the TV Show
   *
   * @auth client
   * @extended full
   *
   * @see [show-summary](https://simkl.docs.apiary.io/reference/tv/summary/get-detail-info-about-the-tv-show}
   */
  id: new (0, _chunkWQ6NSTT2cjs.SimklClientEndpoint)({
    method: _http.HttpMethod.GET,
    url: "/tv/:id",
    opts: {
      auth: _chunkWQ6NSTT2cjs.SimklApiAuthType.Client,
      extends: _chunkWQ6NSTT2cjs.SimklApiExtended.Full,
      parameters: {
        path: {
          id: true
        },
        query: {
          extended: false
        }
      }
    },
    transform: _chunkKBS52LMEcjs.SimklApiTransform.Extends[_chunkWQ6NSTT2cjs.SimklApiExtended.Full]
  }),
  /**
   * Get TV Show episodes
   *
   * @auth client
   * @extended full
   *
   * @see [show-episodes](https://simkl.docs.apiary.io/reference/tv/episodes/get-tv-show-episodes}
   */
  episodes: new (0, _chunkWQ6NSTT2cjs.SimklClientEndpoint)({
    method: _http.HttpMethod.GET,
    url: "/tv/episodes/:id",
    opts: {
      auth: _chunkWQ6NSTT2cjs.SimklApiAuthType.Client,
      extends: _chunkWQ6NSTT2cjs.SimklApiExtended.Full,
      parameters: {
        path: {
          id: true
        },
        query: {
          extended: false
        }
      }
    },
    transform: _chunkKBS52LMEcjs.SimklApiTransform.Extends[_chunkWQ6NSTT2cjs.SimklApiExtended.Full]
  }),
  /**
   * Get trending TV series
   *
   * @auth client
   * @extended discover
   *
   * @see [show-trending](https://simkl.docs.apiary.io/reference/tv/trending/get-trending-tv-series}
   */
  trending: new (0, _chunkWQ6NSTT2cjs.SimklClientEndpoint)({
    method: _http.HttpMethod.GET,
    url: "/tv/trending/:interval",
    opts: {
      auth: _chunkWQ6NSTT2cjs.SimklApiAuthType.Client,
      extends: _chunkWQ6NSTT2cjs.SimklApiExtended.Discover,
      parameters: {
        path: {
          interval: false
        },
        query: {
          extended: false
        }
      }
    },
    transform: _chunkKBS52LMEcjs.SimklApiTransform.Extends[_chunkWQ6NSTT2cjs.SimklApiExtended.Discover]
  }),
  /**
   * Get items filtered by genre, years etc...
   *
   * This endpoint accepts all parameters from the https://simkl.com/tv/all/, select the necessary filters and copy parameters from the url.
   * Genres API duplicates the urls of the Genres on the website so create a filter on the website and add it to genres API.
   *
   * @auth client
   * @pagination true
   *
   * @see [show-genres](https://simkl.docs.apiary.io/reference/tv/genres/get-items-filtered-by-genre,-years-etc...}
   */
  genres: new (0, _chunkWQ6NSTT2cjs.SimklClientEndpoint)({
    method: _http.HttpMethod.GET,
    url: "/tv/genres/:genre/:type/:country/:network/:year/:sort",
    seed: {
      genre: _chunkIF2BWGZLcjs.SimklShowGenreSection.All
    },
    opts: {
      auth: _chunkWQ6NSTT2cjs.SimklApiAuthType.Client,
      pagination: true,
      parameters: {
        path: {
          genre: false,
          type: false,
          country: false,
          network: false,
          year: false,
          sort: false
        },
        query: {
          page: false,
          limit: false
        }
      }
    }
  }),
  /**
   * Get latest premieres
   *
   * @auth client
   * @pagination true
   *
   * @see [show-premieres](https://simkl.docs.apiary.io/reference/tv/premieres/get-latest-premieres}
   */
  premieres: new (0, _chunkWQ6NSTT2cjs.SimklClientEndpoint)({
    method: _http.HttpMethod.GET,
    url: "/tv/premieres/:param",
    seed: {
      param: _chunkP6V2PU4Bcjs.SimklPremiereParam.New
    },
    opts: {
      auth: _chunkWQ6NSTT2cjs.SimklApiAuthType.Client,
      pagination: true,
      parameters: {
        path: {
          param: true
        },
        query: {
          type: false,
          page: false,
          limit: false
        }
      }
    }
  }),
  /**
   * Get Airing TV Shows
   *
   * @auth client
   *
   * @see [show-airing](https://simkl.docs.apiary.io/reference/tv/airing/get-airing-tv-shows}
   */
  airing: new (0, _chunkWQ6NSTT2cjs.SimklClientEndpoint)({
    method: _http.HttpMethod.GET,
    url: "/tv/airing",
    opts: {
      auth: _chunkWQ6NSTT2cjs.SimklApiAuthType.Client,
      parameters: {
        query: {
          date: false,
          sort: false
        }
      }
    }
  }),
  /**
   * Get best of all TV Shows
   *
   * @auth client
   *
   * @see [show-best](https://simkl.docs.apiary.io/reference/tv/best/get-best-of-all-tv-shows}
   */
  best: new (0, _chunkWQ6NSTT2cjs.SimklClientEndpoint)({
    method: _http.HttpMethod.GET,
    url: "/tv/best/:filter",
    seed: {
      filter: _chunkP6V2PU4Bcjs.SimklBestFilter.All
    },
    opts: {
      auth: _chunkWQ6NSTT2cjs.SimklApiAuthType.Client,
      parameters: {
        path: {
          filter: true
        },
        query: {
          type: false
        }
      }
    }
  })
};



exports.show = show;
