"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _nullishCoalesce(lhs, rhsFn) { if (lhs != null) { return lhs; } else { return rhsFn(); } } function _optionalChain(ops) { let lastAccessLHS = undefined; let value = ops[0]; let i = 1; while (i < ops.length) { const op = ops[i]; const fn = ops[i + 1]; i += 2; if ((op === 'optionalAccess' || op === 'optionalCall') && value == null) { return undefined; } if (op === 'access' || op === 'optionalAccess') { lastAccessLHS = value; value = fn(value); } else if (op === 'call' || op === 'optionalCall') { value = fn((...args) => value.call(lastAccessLHS, ...args)); lastAccessLHS = undefined; } } return value; }

var _chunkBTUVJIO6cjs = require('./chunk-BTUVJIO6.cjs');


var _chunkBPOU5IWNcjs = require('./chunk-BPOU5IWN.cjs');



var _chunkULGRH227cjs = require('./chunk-ULGRH227.cjs');






var _chunkPIQLDQGTcjs = require('./chunk-PIQLDQGT.cjs');

// lib/clients/simkl-client.ts
var _crypto = require('@dvcol/common-utils/common/crypto');
var SimklClient = class extends _chunkBPOU5IWNcjs.BaseSimklClient {
  
  
  /**
   * The url to redirect to after the user has authorized the application.
   */
  get redirectUri() {
    return this.settings.redirect_uri;
  }
  /**
   * Creates an instance of MalClient, with the necessary endpoints and settings.
   * @param settings - The settings for the client.
   * @param authentication - The authentication for the client.
   * @param api - The API endpoints for the client.
   */
  constructor(settings, authentication = {}, api = _chunkBTUVJIO6cjs.minimalSimklApi) {
    super(settings, authentication, api);
  }
  _clearPolling() {
    if (this.polling === void 0) return;
    clearInterval(this.polling);
    this.polling = void 0;
  }
  _clearPoll() {
    this.poll = void 0;
  }
  /**
   * Initiates the OAuth process by redirecting to the Simkl website.
   * Users will be prompted to sign in and authorize the application.
   *
   * Once redirected back to the application, the code should be exchanged for an access token.
   *
   * @param redirect - The type of redirect to use (defaults to manual).
   * @param redirect_uri - The URL to redirect to after the user has authorized the application (defaults to client settings).
   * @param request.code_challenge - The code challenge to match against the code verifier.
   * @param request.state - The optional CSRF token to verify the state.
   * @param request - Additional parameters for the authorization request.
   * @returns A promise resolving to the response from the Simkl website.
   *
   * @see [authorize]{@link https://simkl.docs.apiary.io/#reference/authentication-oauth-2.0/authorize/authorize-application}
   */
  async authorize({ redirect, redirect_uri, ...request } = {}) {
    const state = _nullishCoalesce(request.state, () => ( _crypto.randomHex.call(void 0, )));
    this.updateAuth((auth) => ({ ...auth, state }));
    const init = { credentials: "omit" };
    if (redirect) init.redirect = redirect;
    return this.authentication.authorize(
      {
        response_type: "code",
        client_id: this.settings.client_id,
        redirect_uri: _nullishCoalesce(redirect_uri, () => ( this.settings.redirect_uri)),
        ...request,
        state
      },
      init
    );
  }
  /**
   * Initiates the OAuth process by generating a URL to the Simkl website.
   * Users will be prompted to sign in and authorize the application.
   *
   * Once redirected back to the application, the code should be exchanged for an access token with {@link exchangeCodeForToken}.
   *
   * @param redirect_uri - The URL to redirect to after the user has authorized the application (defaults to client settings).
   * @param request - Additional parameters for the authorization request.
   * @returns A promise resolving to the response from the Simkl website.
   *
   * @see [authorize]{@link https://simkl.docs.apiary.io/#reference/authentication-oauth-2.0/authorize/authorize-application}
   */
  resolveAuthorizeUrl({ redirect_uri, ...request } = {}) {
    const state = _nullishCoalesce(request.state, () => ( _crypto.randomHex.call(void 0, )));
    this.updateAuth((auth) => ({ ...auth, state }));
    return this.authentication.authorize.resolve({
      response_type: "code",
      client_id: this.settings.client_id,
      redirect_uri: _nullishCoalesce(redirect_uri, () => ( this.settings.redirect_uri)),
      ...request,
      state
    }).toString();
  }
  /**
   * Exchanges the authorization code obtained after the user has authorized the application with {@link authorize} or {@link resolveAuthorizeUrl}.
   *
   * @param  code - The authorization code obtained from the user.
   * @param code_verifier - The code verifier to match again the code challenge.
   * @param redirect_uri - The URL to redirect to after the user has authorized the application (defaults to client settings).
   * @param  state - The optional CSRF token to verify the state.
   *
   * @returns  A promise resolving to the Trakt authentication information.
   *
   * @throws Error Throws an error if the CSRF token is invalid.
   */
  async exchangeCodeForToken({ code, redirect_uri }, state) {
    if (state && state !== this.auth.state) throw new (0, _chunkPIQLDQGTcjs.SimklInvalidCsrfError)({ state, expected: this.auth.state });
    const response = await this.authentication.token({
      code,
      client_id: this.settings.client_id,
      client_secret: this.settings.client_secret,
      redirect_uri: _nullishCoalesce(redirect_uri, () => ( this.settings.redirect_uri))
    });
    const token = await response.json();
    this.updateAuth({ created: Date.now(), ...token, state });
    return this.auth;
  }
  /**
   * Gets the device code for initiating device authentication.
   *
   * The code should then be used in conjunction with the {@link pollWithDeviceCode} method to finish authentication.
   *
   * @returns A promise resolving to the device authentication information.
   */
  async getDeviceCode(redirect) {
    try {
      const response = await this.authentication.pin.code({ client_id: this.settings.client_id, redirect });
      this.poll = await response.json();
      return this.poll;
    } catch (error) {
      this._clearPoll();
      throw error;
    }
  }
  /**
   * Polls the device authentication endpoint to complete the authentication.
   * If the timeout is reached, the polling is cancelled and an error is thrown.
   * If the authentication is successful, the polling is cancelled and the authentication information is returned.
   *
   * @param poll - The device authentication information.
   * @param timeout - The timeout in milliseconds.
   *
   * @returns A promise resolving to the authentication information if successful
   */
  async _devicePolling(poll = this.poll, timeout) {
    if (this.polling === void 0) return;
    if (!_optionalChain([poll, 'optionalAccess', _ => _.user_code])) throw new (0, _chunkPIQLDQGTcjs.SimklInvalidParameterError)("No user code found.");
    if (!this.settings.client_id) throw new (0, _chunkPIQLDQGTcjs.SimklInvalidParameterError)("No client ID found.");
    if (timeout <= Date.now()) throw new (0, _chunkPIQLDQGTcjs.SimklPollingExpiredError)();
    const response = await this.authentication.pin.status({
      client_id: this.settings.client_id,
      user_code: poll.user_code
    });
    const auth = await response.json();
    if (auth.result === _chunkULGRH227cjs.SimklPollingResult.OK) {
      this.updateAuth((_auth) => ({ ..._auth, created: Date.now(), access_token: auth.access_token }));
      return this.auth;
    }
    if (auth.message === _chunkULGRH227cjs.SimklPollingStatus.Pending) {
      console.info("Polling in progress...");
      return null;
    }
    throw new (0, _chunkPIQLDQGTcjs.SimklApiError)(auth.message);
  }
  /**
   * Initiates polling with the code obtained by {@link getDeviceCode} to complete device authentication.
   *
   * @param  poll - The device authentication information.
   *
   * @returns  A promise resolving to the completed authentication information or `undefined`.
   */
  pollWithDeviceCode(poll = this.poll) {
    if (!_optionalChain([poll, 'optionalAccess', _2 => _2.user_code])) throw new (0, _chunkPIQLDQGTcjs.SimklInvalidParameterError)("No device code found.");
    if (this.polling) {
      this._clearPolling();
      console.warn("Polling already in progress, cancelling previous one...");
    }
    const timeout = Date.now() + poll.expires_in * 1e3;
    let reject;
    const promise$ = new Promise((_resolve, _reject) => {
      reject = _reject;
      const pollDevice = async () => {
        try {
          const body = await this._devicePolling(poll, timeout);
          if (!body) return;
          _resolve(body);
        } catch (err) {
          _reject(err);
        }
        this._clearPolling();
        this._clearPoll();
      };
      this.polling = setInterval(pollDevice, poll.interval * 1e3);
    });
    promise$.cancel = () => {
      this._clearPolling();
      this._clearPoll();
      console.warn("Polling cancelled");
      reject(new (0, _chunkPIQLDQGTcjs.SimklPollingCancelledError)());
    };
    return promise$;
  }
  /**
   * Imports the provided authentication information into the client.
   * If the access token is expired, it attempts to refresh it.
   *
   * @param auth - The authentication information to import.
   *
   * @returns A promise resolving to the imported authentication information.
   */
  importAuthentication(auth = {}) {
    this.updateAuth(auth);
    return this.auth;
  }
};



exports.SimklClient = SimklClient;
