import {
  SimklApiTransform
} from "./chunk-UUWXYJQS.js";
import {
  SimklApiAuthType,
  SimklApiExtended,
  SimklClientEndpoint
} from "./chunk-3HNK4KUT.js";

// lib/api/endpoints/movie.endpoint.ts
import { HttpMethod } from "@dvcol/common-utils/http";
var movie = {
  /**
   * Get detail info about the movie
   *
   * @auth client
   * @extended full
   *
   * @see [movie-summary](https://simkl.docs.apiary.io/reference/movies/summary/get-detail-info-about-the-movie}
   */
  id: new SimklClientEndpoint({
    method: HttpMethod.GET,
    url: "/movies/:id",
    opts: {
      auth: SimklApiAuthType.Client,
      extends: SimklApiExtended.Full,
      parameters: {
        path: {
          id: true
        },
        query: {
          extended: false
        }
      }
    },
    transform: SimklApiTransform.Extends[SimklApiExtended.Full]
  }),
  /**
   * Get trending movies
   *
   * @auth client
   * @extended discover
   *
   * @see [movie-trending](https://simkl.docs.apiary.io/reference/movies/trending/get-trending-movies}
   */
  trending: new SimklClientEndpoint({
    method: HttpMethod.GET,
    url: "/movies/trending/:interval",
    opts: {
      auth: SimklApiAuthType.Client,
      extends: SimklApiExtended.Discover,
      parameters: {
        path: {
          interval: false
        },
        query: {
          extended: false
        }
      }
    },
    transform: SimklApiTransform.Extends[SimklApiExtended.Discover]
  })
};

export {
  movie
};
