import {
  SimklApiAuthType,
  SimklClientEndpoint
} from "./chunk-3HNK4KUT.js";

// lib/api/endpoints/redirect.endpoint.ts
import { HttpMethod } from "@dvcol/common-utils/http";
var redirect = {
  /**
   * Use this if you want to make a redirect to Simkl or (fast post) to Twitter using show's title or id. It will return "location" header.
   *
   * The more parameters you'll pass, the more accurate redirect will be.
   *
   * Type show combine tv and anime types.
   *
   * The response will include the "location" header (browser redirect) where the user should be redirected.
   *
   * @see [redirect]{@link https://simkl.docs.apiary.io/reference/redirect/redirect-to-simkl-trailer-or-twitter/redirect}
   */
  to: new SimklClientEndpoint({
    method: HttpMethod.GET,
    url: "/redirect",
    opts: {
      cache: false,
      parameters: {
        query: {
          to: false,
          title: false,
          year: false,
          season: false,
          episode: false,
          type: false,
          simkl: false,
          imdb: false,
          tvdb: false,
          tmdb: false,
          anidb: false,
          mal: false,
          anilist: false,
          hulu: false,
          netflix: false,
          crunchyroll: false,
          kitsu: false,
          livechart: false,
          anisearch: false,
          animeplanet: false,
          traktslug: false,
          letterboxd: false
        }
      }
    }
  }),
  /**
   * On first use, the user will be shown the Allow dialog to allow your app mark as watched in his profile and then redirected to the episode or movie with "Marked as watched notification".
   *
   * Currently supports marking episodes in TV Shows and Anime.
   *
   * @auth client
   *
   * @see [watched]{@link https://simkl.docs.apiary.io/reference/redirect/redirect-to-simkl-trailer-or-twitter/mark-as-watched}
   */
  watched: new SimklClientEndpoint({
    method: HttpMethod.GET,
    url: "/redirect",
    seed: {
      to: "watched"
    },
    opts: {
      cache: false,
      auth: SimklApiAuthType.Client,
      parameters: {
        query: {
          to: true,
          client_id: false,
          title: false,
          year: false,
          season: false,
          episode: false,
          type: false,
          simkl: false,
          imdb: false,
          tvdb: false,
          tmdb: false,
          anidb: false,
          mal: false,
          anilist: false,
          hulu: false,
          netflix: false,
          crunchyroll: false,
          kitsu: false,
          livechart: false,
          anisearch: false,
          animeplanet: false,
          traktslug: false,
          letterboxd: false
        }
      }
    }
  })
};

export {
  redirect
};
