"use strict";Object.defineProperty(exports, "__esModule", {value: true});


var _chunkWQ6NSTT2cjs = require('./chunk-WQ6NSTT2.cjs');

// lib/api/endpoints/user.endpoint.ts
var _http = require('@dvcol/common-utils/http');
var user = {
  /**
   * Get images for user's last watched TV Show or Movie.
   * Useful for example to create an app that will update user's wallpaper on computer or phone
   *
   * @see [documentation]{@link https://simkl.docs.apiary.io/reference/users/last-watched-arts}
   */
  arts: {
    /**
     * Get last watched images and data
     *
     * Will reply with user's id, Show\Movie URL, Show\Movie title, large poster, and large fanart image.
     *
     * @auth client
     *
     * @see [last-art](https://simkl.docs.apiary.io/reference/users/last-watched-arts/get-last-watched-images-and-data}
     */
    last: new (0, _chunkWQ6NSTT2cjs.SimklClientEndpoint)({
      method: _http.HttpMethod.GET,
      url: "/users/recently-watched-background/:id",
      opts: {
        auth: _chunkWQ6NSTT2cjs.SimklApiAuthType.Client,
        parameters: {
          path: {
            id: true
          }
        }
      }
    }),
    /**
     * Will simply redirect to the image for your app to download or display.
     *
     * @auth client
     *
     * @see [redirect-last-art](https://simkl.docs.apiary.io/reference/users/last-watched-arts/redirect-to-last-watched-image
     */
    redirect: new (0, _chunkWQ6NSTT2cjs.SimklClientEndpoint)({
      method: _http.HttpMethod.GET,
      url: "/users/recently-watched-background/:id",
      opts: {
        auth: _chunkWQ6NSTT2cjs.SimklApiAuthType.Client,
        parameters: {
          path: {
            id: true
          },
          query: {
            image: true,
            client_id: false
          }
        }
      }
    })
  },
  /**
   * You can sync user's settings with your apps/site settings
   *
   * @auth user
   *
   * @see [settings](https://simkl.docs.apiary.io/reference/users/settings/receive-settings}
   */
  settings: new (0, _chunkWQ6NSTT2cjs.SimklClientEndpoint)({
    method: _http.HttpMethod.GET,
    url: "/users/settings",
    opts: {
      auth: _chunkWQ6NSTT2cjs.SimklApiAuthType.User
    }
  }),
  /**
   * Get all info about user's watched movies, tv shows, anime and episodes.
   * Some users profiles are private so you need to pass token to see their stats.
   *
   * @auth user or client - require token for private profiles.
   *
   * @see [stats](https://simkl.docs.apiary.io/reference/users/stats/get-watched-statistics}
   */
  stats: new (0, _chunkWQ6NSTT2cjs.SimklClientEndpoint)({
    method: _http.HttpMethod.GET,
    url: "/users/:id/stats",
    opts: {
      auth: _chunkWQ6NSTT2cjs.SimklApiAuthType.Both,
      parameters: {
        path: {
          id: true
        }
      }
    }
  })
};



exports.user = user;
