import { SimklAnimeTypes } from './simkl-anime.model.js';
import { SimklIds, SimklMediaTypes, SimklEntityType, SimklMediaType } from './simkl-common.model.js';
import { SimklEpisodeMinimal } from './simkl-episode.model.js';
import { SimklRatings } from './simkl-rating.model.js';
import './simkl-client.model.js';
import '@dvcol/base-http-client';
import '@dvcol/common-utils/common/models';
import '@dvcol/common-utils/http/fetch';

type SimklMonth = 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | 11 | 12;
type SimklCalendarMonthRequest = {
    year?: string | number;
    month?: string | SimklMonth;
};
type SimklCalendarEntity = {
    title: string;
    poster?: string;
    date: string;
    release_date: string;
    rank: number;
    url: string;
};
type SimklCalendarMovie = SimklCalendarEntity & {
    ids: SimklIds<'simkl_id' | 'slug' | 'tmdb' | 'imdb'>;
    ratings: SimklRatings<'simkl'>;
};
type SimklCalendarShow = SimklCalendarEntity & {
    ids: SimklIds<'simkl_id' | 'slug' | 'tmdb' | 'imdb'>;
    episode: SimklEpisodeMinimal;
    ratings: SimklRatings<'simkl'>;
};
type SimklCalendarAnime = SimklCalendarEntity & {
    ids: SimklIds<'simkl_id' | 'slug' | 'tmdb' | 'mal'>;
    episode: Omit<SimklEpisodeMinimal, 'season'>;
    ratings: SimklRatings<'simkl'>;
    anime_type: SimklAnimeTypes;
};
type SimklCalendar<T extends SimklMediaTypes | typeof SimklEntityType.Unknown = typeof SimklEntityType.Unknown> = T extends typeof SimklMediaType.Movie ? SimklCalendarMovie : T extends typeof SimklMediaType.Show ? SimklCalendarShow : T extends typeof SimklMediaType.Anime ? SimklCalendarAnime : SimklCalendarMovie | SimklCalendarShow | SimklCalendarAnime;

export type { SimklCalendar, SimklCalendarAnime, SimklCalendarEntity, SimklCalendarMonthRequest, SimklCalendarMovie, SimklCalendarShow, SimklMonth };
