type SimklIdsShort = {
    simkl: number;
    simkl_id: number;
    slug: string;
    imdb: number | string;
    tvdb: number | string;
    tmdb: number | string;
    mal: number | string;
};
type SimklIdsExtended = SimklIdsShort & {
    netflix: number | string;
    hulu: string;
    anidb: number | string;
    animeplanet: string;
    anilist: number | string;
    ann: number | string;
    schel: number | string;
    anison: number | string;
    anisearch: number | string;
    crunchyroll: string;
    kitsu: number | string;
    livechart: number | string;
    allcin: number | string;
    tvdbslug: string;
    zap2it: string;
    tmdbtv: number | string;
    traktslug: string;
    tvdbmslug: string;
    tvdbm: number | string;
    letterslug: string;
    moviedb: number | string;
    fb: string;
    instagram: string;
    tw: string;
    wikien: string;
    wikijp: string;
    offjp: string;
    offen: string;
};
type SimklIds<K extends keyof T, T = SimklIdsExtended> = Partial<SimklIdsExtended> & {
    [P in K]: T[P];
};
declare const SimklEntityType: {
    readonly Short: "short";
    readonly Extended: "extended";
    readonly Unknown: "unknown";
};
type SimklEntityTypes = (typeof SimklEntityType)[keyof typeof SimklEntityType];
declare const SimklMediaType: {
    readonly Movie: "movie";
    readonly Show: "show";
    readonly Anime: "anime";
};
type SimklMediaTypes = (typeof SimklMediaType)[keyof typeof SimklMediaType];
type SimklIdQuery = {
    simkl?: number | string;
    /** can be IMDB ID or full IMDB URL. All other parameters can be empty if this one specified. */
    imdb?: number | string;
    /** TVDB ID. All other parameters can be empty if this one specified. */
    tvdb?: number | string;
    /** The Movie Database (TMDb) ID. To search TV Shows specify type parameter. All other parameters can be empty if this one specified. */
    tmdb?: false;
    /** AniDB ID. All other parameters can be empty if this one specified. */
    anidb?: number | string;
    /** MyAnimeList id */
    mal?: number | string;
    /** AniList ID */
    anilist?: number | string;
    /** hulu_id. All other parameters can be empty if this one specified. */
    hulu?: number | string;
    /** Netflix movieid, this parameter is in beta and may not work. */
    netflix?: number | string;
    /** Crunchyroll ID. You can pass episode ID or url ID */
    crunchyroll?: number | string;
    kitsu?: number | string;
    livechart?: number | string;
    anisearch?: number | string;
    animeplanet?: string;
    traktslug?: string;
    letterboxd?: string;
};
type SimklInfoQuery = {
    /** TV show, anime, or movie title. */
    title?: string;
    /** Release year. */
    year?: number | string;
    /**
     * If set, movies will be ignored. Anime do not have seasons.
     * Default: 1
     */
    season?: number | string;
    /**
     * If set, movies will be ignored.
     */
    episode?: number | string;
    /**
     * Required for better search by tmdb title field.
     * - Use 'show' to search both anime and tv.
     * - Use 'anime' to limit the search by title in anime.
     * - 'movie' is theatrical movie, not anime movie.
     */
    type?: SimklEntityTypes;
};
type SimklCommonQuery = SimklIdQuery & SimklInfoQuery;
type SimklAirDate = {
    day: string;
    time: string;
    timezone: string;
};
declare const SimklAnimeAndShowStatus: {
    readonly Airing: "airing";
    readonly Ongoing: "ongoing";
    readonly Ended: "ended";
    readonly Tba: "tba";
};
type SimklAnimeAndShowStatuses = (typeof SimklAnimeAndShowStatus)[keyof typeof SimklAnimeAndShowStatus];
declare const SimklMovieStatus: {
    readonly Released: "released";
    readonly Upcoming: "upcoming";
};
type SimklMovieStatuses = (typeof SimklMovieStatus)[keyof typeof SimklMovieStatus];
declare const SimklMediaStatus: {
    readonly Released: "released";
    readonly Upcoming: "upcoming";
    readonly Airing: "airing";
    readonly Ongoing: "ongoing";
    readonly Ended: "ended";
    readonly Tba: "tba";
};
type SimklMediaStatuses = (typeof SimklMediaStatus)[keyof typeof SimklMediaStatus];
type SimklTrailer = {
    name: string;
    youtube: string;
    size: number;
};
declare const SimklTrendingInterval: {
    readonly Today: "today";
    readonly Week: "week";
    readonly Month: "month";
};
type SimklTrendingIntervals = (typeof SimklTrendingInterval)[keyof typeof SimklTrendingInterval];
declare const SimklGenreYear: {
    readonly All: "all-years";
    readonly Today: "today";
    readonly ThisWeek: "this-week";
    readonly ThisMonth: "this-month";
    readonly ThisYear: "this-year";
};
type SimklGenreYears = (typeof SimklGenreYear)[keyof typeof SimklGenreYear];
declare const SimklGenreSort: {
    readonly PopularToday: "popular-today";
    readonly PopularThisWeek: "popular-this-week";
    readonly PopularThisMonth: "popular-this-month";
    readonly Rank: "rank";
    readonly Votes: "votes";
    readonly ReleaseDate: "release-date";
    readonly LastAirDate: "last-air-date";
    readonly AlphabetAZ: "a-z";
    readonly AlphabetZA: "z-a";
};
type SimklGenreSorts = (typeof SimklGenreSort)[keyof typeof SimklGenreSort];
declare const SimklPremiereParam: {
    readonly New: "new";
    readonly Soon: "soon";
};
type SimklPremiereParams = (typeof SimklPremiereParam)[keyof typeof SimklPremiereParam];
declare const SimklPremiereDate: {
    readonly Today: "today";
    readonly Tomorrow: "tomorrow";
};
type SimklPremiereDates = (typeof SimklPremiereDate)[keyof typeof SimklPremiereDate];
declare const SimklAiringSort: {
    readonly Time: "time";
    readonly Rank: "rank";
    readonly Popularity: "popularity";
};
type SimklAiringSorts = (typeof SimklAiringSort)[keyof typeof SimklAiringSort];
declare const SimklBestFilter: {
    readonly Year: "year";
    readonly Month: "month";
    readonly All: "all";
    readonly Voted: "voted";
    readonly Watched: "watched";
};
type SimklBestFilters = (typeof SimklBestFilter)[keyof typeof SimklBestFilter];
type SimklAlternativeTitle = {
    name: string;
    lang: string;
    type: 'official' | 'synonym' | string;
};

export { type SimklAirDate, SimklAiringSort, type SimklAiringSorts, type SimklAlternativeTitle, SimklAnimeAndShowStatus, type SimklAnimeAndShowStatuses, SimklBestFilter, type SimklBestFilters, type SimklCommonQuery, SimklEntityType, type SimklEntityTypes, SimklGenreSort, type SimklGenreSorts, SimklGenreYear, type SimklGenreYears, type SimklIdQuery, type SimklIds, type SimklIdsExtended, type SimklIdsShort, type SimklInfoQuery, SimklMediaStatus, type SimklMediaStatuses, SimklMediaType, type SimklMediaTypes, SimklMovieStatus, type SimklMovieStatuses, SimklPremiereDate, type SimklPremiereDates, SimklPremiereParam, type SimklPremiereParams, type SimklTrailer, SimklTrendingInterval, type SimklTrendingIntervals };
