/**
 * Url structure: {domain}{prefix}{image_url}{suffix}{extension}
 *
 * @see [documentation]{@link https://simkl.docs.apiary.io/#introduction/about-simkl-api/images}
 **/
declare const SimklApiImages: {
    readonly Endpoint: "https://wsrv.nl/?url=https://simkl.in";
    readonly Prefix: {
        readonly Poster: "posters";
        readonly Fanart: "fanart";
        readonly Episode: "episodes";
        readonly Avatars: "avatars";
        readonly Comments: "comments";
    };
    readonly Suffix: {
        readonly Poster: {
            /** 600x338 */
            readonly Wide: "_w";
            /** 340x * */
            readonly Large: "_m";
            /** 190x279(285) */
            readonly Medium: "_ca";
            /** 170x250(256) */
            readonly Small: "_c";
            /** 84x124 */
            readonly Tiny: "_cm";
            /** 40x57 */
            readonly Thumb: "_s";
        };
        readonly Fanart: {
            /** (darker, small KB)	* x * (original size) */
            readonly Darker: "_d";
            /** 1920x1080 */
            readonly FullHD: "_medium";
            /** 960x540 */
            readonly Mobile: "_mobile";
            /** 600x338 */
            readonly Wide: "_w";
            /** 48x27 */
            readonly Thumb: "_s48";
        };
        readonly Episode: {
            /** 600x338 */
            readonly Wide: "_w";
            /** 210x118 */
            readonly Small: "_c";
            /** 112x63 */
            readonly Thumb: "_m";
        };
        readonly Avatars: {
            /** 24x24 */
            readonly w24: "_24";
            /** 100x100 */
            readonly w100: "_100";
            /** 200x200 */
            readonly w200: "";
            /** 256x256 */
            readonly w256: "_256";
            /** 512x512 */
            readonly w512: "_512";
        };
    };
};
type SimklApiImagePrefix = (typeof SimklApiImages)['Prefix'][keyof (typeof SimklApiImages)['Prefix']];
type SimklApiImageSuffix = (typeof SimklApiImages)['Suffix'][keyof (typeof SimklApiImages)['Suffix']];
type SimklApiImageExtension = '.jpg' | '.webp';
/**
 * Url structure: {domain}{prefix}{image_url}{suffix}{extension}
 *
 * The images with the same URL never change.
 * Do not re-download the same image multiple times.
 * We recommend caching the images on your server.
 *
 * @see [documentation]{@link https://simkl.docs.apiary.io/#introduction/about-simkl-api/images}
 **/
declare const getSimklImageUrl: ({ url, prefix, suffix, extension, }: {
    url: string;
    prefix: SimklApiImagePrefix;
    suffix: SimklApiImageSuffix;
    extension: SimklApiImageExtension;
}) => URL;

export { type SimklApiImageExtension, type SimklApiImagePrefix, type SimklApiImageSuffix, SimklApiImages, getSimklImageUrl };
